<?php
/**
 * Created by PhpStorm.
 * User: zhuangxin
 * Date: 16-9-9
 * Time: 下午4:15
 */

namespace App\Works\Model;

use App\Works\Model\Details as DetailModel;
use App\Traits\Models;
use \Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Works extends Model
{
    use Models;
    protected $table = "myp_works";
    public $timestamps = false;

    public function __construct(array $attributes = [])
    {
        parent::__construct($attributes);
        $this->beforeValidationOnCreate();
        $this->skipAttributesOnUpdate();
    }

    public function beforeValidationOnCreate()
    {
        $this->comment_count = 0;
        $this->like_count = 0;
        $this->collect_count = 0;
        $this->look_count = 0;
        $this->from = 0;
        $this->is_hidden = 0;
        $this->ref_count = 0;
        $this->count = 0;
        $this->create_time = date("Y-m-d H:i:s",time());
    }

    public function skipAttributesOnUpdate()
    {
        $this->guard(['create_time','comment_count','like_count','collect_count','look_count']);
    }

    public function relation_sets()
    {
        return $this->hasMany(\App\Sets\Model\Works::class,"works_id")->where('is_del',0)->select("sets_id");
    }

    public function relation_category()
    {
        return $this->hasMany(Category::class,"works_id")->where('is_del',0);
    }

    public function relation_detail()
    {
        return $this->hasMany(Details::class,"works_id")->where('is_del',0);
    }

    public function relation_comments()
    {
        return $this->hasMany(Comments::class,"works_id")->where('is_del',0);
    }

    public function relation_keywords()
    {
        return $this->hasMany(Keywords::class,"works_id")->where('is_del',0);
    }

    public function images(array $resources)
    {
        $details = [];
        foreach ($resources as $url) {
            $details = new DetailModel($url);
        }
        return $this->relation_detail()->saveMany($details);
    }

    public static function newWorks(array $data)
    {
        $model = new self;
        DB::beginTransaction();
        try {
            $isSaved = $model->fill($data)->save();
            if (!$isSaved){
                throw new \Exception("保存失败");
            }
            if (isset($data['images']) && !empty($data['images'])) {
                if (!$model->images($data['images'])) {
                    throw new \Exception("保存图片失败");
                }
            }
        } catch (\Exception $e) {
            DB::rollBack();
            return false;
        }
        DB::commit();
        return $model;
    }
}